bayespy.inference.vmp.nodes.expfamily.ExponentialFamily.get_mask
================================================================

.. currentmodule:: bayespy.inference.vmp.nodes.expfamily

.. automethod:: ExponentialFamily.get_mask